﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using Moba.GenericGUIICE;

namespace ICEInitialisationLeak
{
    public partial class Form1 : Form
    {
        private Ice.InitializationData mInitData = null;
        private string mInterfaceProtocol;
        private string mInterfaceHost;
        private string mInterfacePort;
        private uint mSessionTimeOut;
        private Ice.Communicator mIce;
        private Glacier2.RouterPrx mGlacierRouter;
        private string mCategory;
        private ICommunicationICEPrx mCommunicationICEProxy = null;



        public Form1()
        {
            InitializeComponent();
            mInterfaceHost = "172.16.28.22";
            mInterfacePort = "4502";
            mInterfaceProtocol = "default";
            mSessionTimeOut = 3000;
        }

        private void btnInitialise_Click(object sender, EventArgs e)
        {
            mInitData = new Ice.InitializationData();
            mInitData.properties = Ice.Util.createProperties();

            mInitData.properties.setProperty("CommunicationICE.Proxy", "CommunicationICEInterface:default -h 127.0.0.1 -p 10000");
            mInitData.properties.setProperty("TopicManager.Proxy", "DemoIceStorm/TopicManager:default -h 127.0.0.1 -p 10001");
            mInitData.properties.setProperty("Ice.Default.Router", "DemoGlacier2/router:" + mInterfaceProtocol + " -h " + mInterfaceHost + " -p " + mInterfacePort + " -t " + mSessionTimeOut);
            mInitData.properties.setProperty("MobaGlacier.Router", "DemoGlacier2/router:" + mInterfaceProtocol + " -h " + mInterfaceHost + " -p " + mInterfacePort + " -t " + mSessionTimeOut);
            mInitData.properties.setProperty("MobaGlacier.Endpoints", "");
            mInitData.properties.setProperty("Ice.ACM.Client", "0");
            mInitData.properties.setProperty("Ice.RetryIntervals", "-1");

            mIce = Ice.Util.initialize(mInitData);

            Ice.RouterPrx lRouter = mIce.getDefaultRouter();
            mGlacierRouter = Glacier2.RouterPrxHelper.checkedCast(lRouter);

            string lName = "";
            string lPassword = "";
            mGlacierRouter.createSession(lName, lPassword);
            mCategory = mGlacierRouter.getCategoryForClient();

            Ice.ObjectPrx lModuleProxy = mIce.propertyToProxy("CommunicationICE.Proxy");
            mCommunicationICEProxy = ICommunicationICEPrxHelper.checkedCast(lModuleProxy);
            if (null != mCommunicationICEProxy)
            {
                lblTxt.Text = "Initialisation: Success";
            }
            else
            {
                lblTxt.Text = "Initialisation: Error";
            }
        }

        private void btnRead_Click(object sender, EventArgs e)
        {
            if (null != mCommunicationICEProxy)
            {
                string lName = "";
                ushort lRetVal;

                lRetVal = (ushort)mCommunicationICEProxy.ReadName(out lName);
                if (0 != lRetVal)
                {
                    lblTxt.Text = "Reading name: Error";
                }
                else
                {
                    lblTxt.Text = "Reading name: success. Name [" + lName + "]";
                }
            }
        }

        private void btnTerminate_Click(object sender, EventArgs e)
        {
            try
            {
                mGlacierRouter.destroySession();
            }
            catch
            {

            }

            mGlacierRouter = null;

            while (!mIce.isShutdown())
            {
                mIce.shutdown();
            }

            mIce = null;
            mInitData = null;

            GC.Collect();

            lblTxt.Text = "Termination done";
        }
    }
}
